summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/disk.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/disk.c b/src/disk.c
index 63f7a52..6bdd974 100644
--- a/src/disk.c
+++ b/src/disk.c
@@ -369,8 +369,8 @@ int disk_init(struct usb_device_info * dev) {
/* TODO: change 1 to 0 when disk_flash_dev will be implemented */
- /* RX-51 exports MyDocs in first usb device and just first partion, so host system see whole device without MBR table */
- if ( dev->device == DEVICE_RX_51 )
+ /* RX-51 and RM-680 export MyDocs in first usb device and just first partion, so host system see whole device without MBR table */
+ if ( dev->device == DEVICE_RX_51 || dev->device == DEVICE_RM_680 )
fd = disk_open_dev(maj1, min1, -1, 1);
/* Other devices can export SD card as first partition and export whole mmc device, so host system will see MBR table */
else if ( maj2 != -1 && min2 != -1 )